==> stagehand-1.0.1.tar.gz: lib/generators/web_angular_data.dart <==
// Copyright (c) 2014, Google Inc. Please see the AUTHORS file for details.
// All rights reserved. Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

const List<String> data = const [
  ".gitignore",
  "text",
  """IyBGaWxlcyBhbmQgZGlyZWN0b3JpZXMgY3JlYXRlZCBieSBwdWIKLnBhY2thZ2VzCi5wdWIvCmJ1
aWxkLwpwYWNrYWdlcwpwdWJzcGVjLmxvY2sgIyAoUmVtb3ZlIHRoaXMgcGF0dGVybiBpZiB5b3Ug
d2lzaCB0byBjaGVjayBpbiB5b3VyIGxvY2sgZmlsZSkKCiMgRmlsZXMgY3JlYXRlZCBieSBkYXJ0
MmpzCiouZGFydC5qcwoqLnBhcnQuanMKKi5qcy5kZXBzCiouanMubWFwCiouaW5mby5qc29uCgoj
IERpcmVjdG9yeSBjcmVhdGVkIGJ5IGRhcnRkb2MKZG9jL2FwaS8KCiMgSmV0QnJhaW5zIElERXMK
LmlkZWEvCiouaW1sCiouaXByCiouaXdzCg==""",
  "lib/app_component.dart",
  "text",
  """Ly8gQ29weXJpZ2h0IChjKSBfX3llYXJfXywgX19hdXRob3JfXy4gQWxsIHJpZ2h0cyByZXNlcnZl
ZC4gVXNlIG9mIHRoaXMgc291cmNlIGNvZGUKLy8gaXMgZ292ZXJuZWQgYnkgYSBCU0Qtc3R5bGUg
bGljZW5zZSB0aGF0IGNhbiBiZSBmb3VuZCBpbiB0aGUgTElDRU5TRSBmaWxlLgoKaW1wb3J0ICdw
YWNrYWdlOmFuZ3VsYXIyL2FuZ3VsYXIyLmRhcnQnOwoKQENvbXBvbmVudChzZWxlY3RvcjogJ215
LWFwcCcsIHRlbXBsYXRlVXJsOiAnYXBwX2NvbXBvbmVudC5odG1sJykKY2xhc3MgQXBwQ29tcG9u
ZW50IHt9Cg==""",
  "lib/app_component.html",
  "text",
  "PGgxPk15IEZpcnN0IEFuZ3VsYXIgMiBBcHA8L2gxPgo=",
  "pubspec.yaml",
  "text",
  """bmFtZTogX19wcm9qZWN0TmFtZV9fCmRlc2NyaXB0aW9uOiBBIERhcnQgYXBwIHRoYXQgdXNlcyBB
bmd1bGFyIDIKdmVyc2lvbjogMC4wLjEKZW52aXJvbm1lbnQ6CiAgc2RrOiAnPj0xLjEzLjAgPDIu
MC4wJwpkZXBlbmRlbmNpZXM6CiAgYW5ndWxhcjI6IDIuMC4wLWJldGEuNgogIGJyb3dzZXI6IF4w
LjEwLjAKICBkYXJ0X3RvX2pzX3NjcmlwdF9yZXdyaXRlcjogXjAuMS4wCnRyYW5zZm9ybWVyczoK
LSBhbmd1bGFyMjoKICAgIHBsYXRmb3JtX2RpcmVjdGl2ZXM6CiAgICAtICdwYWNrYWdlOmFuZ3Vs
YXIyL2NvbW1vbi5kYXJ0I0NPTU1PTl9ESVJFQ1RJVkVTJwogICAgcGxhdGZvcm1fcGlwZXM6CiAg
ICAtICdwYWNrYWdlOmFuZ3VsYXIyL2NvbW1vbi5kYXJ0I0NPTU1PTl9QSVBFUycKICAgIGVudHJ5
X3BvaW50czogd2ViL21haW4uZGFydAotIGRhcnRfdG9fanNfc2NyaXB0X3Jld3JpdGVyCg==""",
  "web/index.html",
  "text",
  """PCFET0NUWVBFIGh0bWw+CjxodG1sPgogIDxoZWFkPgogICAgPHRpdGxlPl9fcHJvamVjdE5hbWVf
XzwvdGl0bGU+CgogICAgPHNjcmlwdCBkZWZlciBzcmM9Im1haW4uZGFydCIgdHlwZT0iYXBwbGlj
YXRpb24vZGFydCI+PC9zY3JpcHQ+CiAgICA8c2NyaXB0IGRlZmVyIHNyYz0icGFja2FnZXMvYnJv
d3Nlci9kYXJ0LmpzIj48L3NjcmlwdD4KICA8L2hlYWQ+CiAgPGJvZHk+CiAgICA8bXktYXBwPkxv
YWRpbmcuLi48L215LWFwcD4KICA8L2JvZHk+CjwvaHRtbD4K""",
  "web/main.dart",
  "text",
  """Ly8gQ29weXJpZ2h0IChjKSBfX3llYXJfXywgX19hdXRob3JfXy4gQWxsIHJpZ2h0cyByZXNlcnZl
ZC4gVXNlIG9mIHRoaXMgc291cmNlIGNvZGUKLy8gaXMgZ292ZXJuZWQgYnkgYSBCU0Qtc3R5bGUg
bGljZW5zZSB0aGF0IGNhbiBiZSBmb3VuZCBpbiB0aGUgTElDRU5TRSBmaWxlLgoKaW1wb3J0ICdw
YWNrYWdlOmFuZ3VsYXIyL2Jvb3RzdHJhcC5kYXJ0JzsKCmltcG9ydCAncGFja2FnZTpfX3Byb2pl
Y3ROYW1lX18vYXBwX2NvbXBvbmVudC5kYXJ0JzsKCm1haW4oKSB7CiAgYm9vdHN0cmFwKEFwcENv
bXBvbmVudCk7Cn0K"""
];

==> stagehand-1.0.2.tar.gz: lib/generators/web_angular_data.dart <==
// Copyright (c) 2014, Google Inc. Please see the AUTHORS file for details.
// All rights reserved. Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

const List<String> data = const [
  ".gitignore",
  "text",
  """IyBGaWxlcyBhbmQgZGlyZWN0b3JpZXMgY3JlYXRlZCBieSBwdWIKLnBhY2thZ2VzCi5wdWIvCmJ1
aWxkLwpwYWNrYWdlcwpwdWJzcGVjLmxvY2sgIyAoUmVtb3ZlIHRoaXMgcGF0dGVybiBpZiB5b3Ug
d2lzaCB0byBjaGVjayBpbiB5b3VyIGxvY2sgZmlsZSkKCiMgRmlsZXMgY3JlYXRlZCBieSBkYXJ0
MmpzCiouZGFydC5qcwoqLnBhcnQuanMKKi5qcy5kZXBzCiouanMubWFwCiouaW5mby5qc29uCgoj
IERpcmVjdG9yeSBjcmVhdGVkIGJ5IGRhcnRkb2MKZG9jL2FwaS8KCiMgSmV0QnJhaW5zIElERXMK
LmlkZWEvCiouaW1sCiouaXByCiouaXdzCg==""",
  "lib/app_component.dart",
  "text",
  """Ly8gQ29weXJpZ2h0IChjKSBfX3llYXJfXywgX19hdXRob3JfXy4gQWxsIHJpZ2h0cyByZXNlcnZl
ZC4gVXNlIG9mIHRoaXMgc291cmNlIGNvZGUKLy8gaXMgZ292ZXJuZWQgYnkgYSBCU0Qtc3R5bGUg
bGljZW5zZSB0aGF0IGNhbiBiZSBmb3VuZCBpbiB0aGUgTElDRU5TRSBmaWxlLgoKaW1wb3J0ICdw
YWNrYWdlOmFuZ3VsYXIyL2FuZ3VsYXIyLmRhcnQnOwoKQENvbXBvbmVudChzZWxlY3RvcjogJ215
LWFwcCcsIHRlbXBsYXRlVXJsOiAnYXBwX2NvbXBvbmVudC5odG1sJykKY2xhc3MgQXBwQ29tcG9u
ZW50IHt9Cg==""",
  "lib/app_component.html",
  "text",
  "PGgxPk15IEZpcnN0IEFuZ3VsYXIgMiBBcHA8L2gxPgo=",
  "pubspec.yaml",
  "text",
  """bmFtZTogX19wcm9qZWN0TmFtZV9fCmRlc2NyaXB0aW9uOiBBIERhcnQgYXBwIHRoYXQgdXNlcyBB
bmd1bGFyIDIKdmVyc2lvbjogMC4wLjEKZW52aXJvbm1lbnQ6CiAgc2RrOiAnPj0xLjEzLjAgPDIu
MC4wJwpkZXBlbmRlbmNpZXM6CiAgYW5ndWxhcjI6IDIuMC4wLWJldGEuOQogIGJyb3dzZXI6IF4w
LjEwLjAKICBkYXJ0X3RvX2pzX3NjcmlwdF9yZXdyaXRlcjogXjAuMS4wCnRyYW5zZm9ybWVyczoK
LSBhbmd1bGFyMjoKICAgIHBsYXRmb3JtX2RpcmVjdGl2ZXM6CiAgICAtICdwYWNrYWdlOmFuZ3Vs
YXIyL2NvbW1vbi5kYXJ0I0NPTU1PTl9ESVJFQ1RJVkVTJwogICAgcGxhdGZvcm1fcGlwZXM6CiAg
ICAtICdwYWNrYWdlOmFuZ3VsYXIyL2NvbW1vbi5kYXJ0I0NPTU1PTl9QSVBFUycKICAgIGVudHJ5
X3BvaW50czogd2ViL21haW4uZGFydAotIGRhcnRfdG9fanNfc2NyaXB0X3Jld3JpdGVyCg==""",
  "web/index.html",
  "text",
  """PCFET0NUWVBFIGh0bWw+CjxodG1sPgogIDxoZWFkPgogICAgPHRpdGxlPl9fcHJvamVjdE5hbWVf
XzwvdGl0bGU+CgogICAgPHNjcmlwdCBkZWZlciBzcmM9Im1haW4uZGFydCIgdHlwZT0iYXBwbGlj
YXRpb24vZGFydCI+PC9zY3JpcHQ+CiAgICA8c2NyaXB0IGRlZmVyIHNyYz0icGFja2FnZXMvYnJv
d3Nlci9kYXJ0LmpzIj48L3NjcmlwdD4KICA8L2hlYWQ+CiAgPGJvZHk+CiAgICA8bXktYXBwPkxv
YWRpbmcuLi48L215LWFwcD4KICA8L2JvZHk+CjwvaHRtbD4K""",
  "web/main.dart",
  "text",
  """Ly8gQ29weXJpZ2h0IChjKSBfX3llYXJfXywgX19hdXRob3JfXy4gQWxsIHJpZ2h0cyByZXNlcnZl
ZC4gVXNlIG9mIHRoaXMgc291cmNlIGNvZGUKLy8gaXMgZ292ZXJuZWQgYnkgYSBCU0Qtc3R5bGUg
bGljZW5zZSB0aGF0IGNhbiBiZSBmb3VuZCBpbiB0aGUgTElDRU5TRSBmaWxlLgoKaW1wb3J0ICdw
YWNrYWdlOmFuZ3VsYXIyL2Jvb3RzdHJhcC5kYXJ0JzsKCmltcG9ydCAncGFja2FnZTpfX3Byb2pl
Y3ROYW1lX18vYXBwX2NvbXBvbmVudC5kYXJ0JzsKCm1haW4oKSB7CiAgYm9vdHN0cmFwKEFwcENv
bXBvbmVudCk7Cn0K"""
];
